@@ -13,10 +13,11 @@ except ModuleNotFoundError:
         __version__ = setuptools_scm.get_version(fallback_version='?.?.?')
     # FIXME: fallback_version is not available in the buster version
     # (3.2.0-1)
-    except (ModuleNotFoundError, TypeError):
+    except (ModuleNotFoundError, TypeError, LookupError):
         __version__ = '?.?.?'
 from .ifo import IFOS
 from .struct import Struct
+from .plot import plot_trace
 from .plot import plot_budget
 from .plot import plot_noise
 
@@ -115,7 +116,7 @@ def load_budget(name_or_path, freq=None):
 
     else:
         if name_or_path not in IFOS:
-            raise RuntimeError("Unknonw IFO '{}' (available IFOs: {}).".format(
+            raise RuntimeError("Unknown IFO '{}' (available IFOs: {}).".format(
                 name_or_path,
                 IFOS,
             ))
@@ -209,6 +210,6 @@ def gwinc(freq, ifo, source=None, plot=False, PRfixed=True):
             logger.info('BBH Inspiral Range:     ' + str(score.effr0bh) + ' Mpc/ z = ' + str(score.zHorizonBH))
             logger.info('Stochastic Omega: %4.1g Universes' % score.Omega)
 
-        plot_budget(traces, **plot_style)
+        traces.plot(**plot_style)
 
     return score, noises, ifo
